@@ -78,6 +78,13 @@
 #'
 #' @export
 dcr_app <- function(dframe, browser = TRUE) {
+
+
+
+  if(!can_internet()){
+    stop("Please connec to the internet. datacleanr currently relies on an internet connection to provide d3 methods for plotting and data selection. \n These will be packaged into an upcoming version to allow offline use.\n")
+  }
+
   use_data <- dcr_checks(dframe)
 
 
@@ -105,11 +112,11 @@ dcr_app <- function(dframe, browser = TRUE) {
           ui = datacleanr_ui,
           server = function(input, output, session) {
             datacleanr_server(input,
-              output,
-              session,
-              dataset = use_data$dataset,
-              df_name = df_name,
-              is_on_disk = !is.null(use_data$file_path)
+                              output,
+                              session,
+                              dataset = use_data$dataset,
+                              df_name = df_name,
+                              is_on_disk = !is.null(use_data$file_path)
             )
           },
           options = opts_list
